@@ -30,11 +30,9 @@ public:
 	void ctorDone();
 
 signals:
-	void modified();
+	void modified(bool mod);
 
 protected:
-	int spacingHint();
-	int marginHint();
 	bool startedUp;
 	void changed();
 };
