@@ -28,18 +28,20 @@
 #include <QApplication>
 #include <QBoxLayout>
 #include <QCheckBox>
+#include <QFileDialog>
+#include <QGlobalStatic>
 #include <QLabel>
 #include <QMouseEvent>
+#include <QSpinBox>
+#include <QStandardPaths>
 #include <QTimer>
-#include <KFileDialog>
+#include <QUrl>
 #include <KGameRenderer>
-#include <KgTheme>
 #include <KLineEdit>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KNumInput>
 #include <KRandom>
-#include <KStandardDirs>
-#include <KUrl>
+#include <KgTheme>
 #include <Box2D/Dynamics/b2Body.h>
 #include <Box2D/Dynamics/Contacts/b2Contact.h>
 #include <Box2D/Dynamics/b2Fixture.h>
@@ -48,12 +50,12 @@
 
 inline QString makeGroup(int id, int hole, const QString &name, int x, int y)
 {
-	return QString("%1-%2@%3,%4|%5").arg(hole).arg(name).arg(x).arg(y).arg(id);
+	return QStringLiteral("%1-%2@%3,%4|%5").arg(hole).arg(name).arg(x).arg(y).arg(id);
 }
 
 inline QString makeStateGroup(int id, const QString &name)
 {
-	return QString("%1|%2").arg(name).arg(id);
+	return QStringLiteral("%1|%2").arg(name).arg(id);
 }
 
 class KolfContactListener : public b2ContactListener
@@ -86,7 +88,7 @@ class KolfTheme : public KgTheme
 	public:
 		KolfTheme() : KgTheme("pics/default_theme.desktop")
 		{
-			setGraphicsPath(KStandardDirs::locate("appdata", "pics/default_theme.svgz"));
+			setGraphicsPath(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("pics/default_theme.svgz")));
 		}
 };
 
@@ -100,8 +102,8 @@ class KolfRenderer : public KGameRenderer
 		}
 };
 
-K_GLOBAL_STATIC(KolfRenderer, g_renderer)
-K_GLOBAL_STATIC(KolfWorld, g_world)
+Q_GLOBAL_STATIC(KolfRenderer, g_renderer)
+Q_GLOBAL_STATIC(KolfWorld, g_world)
 
 KGameRenderer* Kolf::renderer()
 {
@@ -254,11 +256,8 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	this->holeInfo = holeInfo;
 
 	QVBoxLayout *layout = new QVBoxLayout(this);
-	layout->setMargin( marginHint() );
-	layout->setSpacing( spacingHint() );
 
 	QHBoxLayout *hlayout = new QHBoxLayout;
-	hlayout->setSpacing( spacingHint() );
 	layout->addLayout( hlayout );
 	hlayout->addWidget(new QLabel(i18n("Course name: "), this));
 	KLineEdit *nameEdit = new KLineEdit(holeInfo->untranslatedName(), this);
@@ -266,7 +265,6 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	connect(nameEdit, &KLineEdit::textChanged, this, &HoleConfig::nameChanged);
 
 	hlayout = new QHBoxLayout;
-	hlayout->setSpacing( spacingHint() );
 	layout->addLayout( hlayout );
 	hlayout->addWidget(new QLabel(i18n("Course author: "), this));
 	KLineEdit *authorEdit = new KLineEdit(holeInfo->author(), this);
@@ -276,19 +274,18 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	layout->addStretch();
 
 	hlayout = new QHBoxLayout;
-	hlayout->setSpacing( spacingHint() );
 	layout->addLayout( hlayout );
 	hlayout->addWidget(new QLabel(i18n("Par:"), this));
-	KIntSpinBox *par = new KIntSpinBox(this);
+	QSpinBox *par = new QSpinBox(this);
 	par->setRange( 1, 15 );
 	par->setSingleStep( 1 );
 	par->setValue(holeInfo->par());
 	hlayout->addWidget(par);
-	connect(par, static_cast<void (KIntSpinBox::*)(int)>(&KIntSpinBox::valueChanged), this, &HoleConfig::parChanged);
+	connect(par, QOverload<int>::of(&QSpinBox::valueChanged), this, &HoleConfig::parChanged);
 	hlayout->addStretch();
 
 	hlayout->addWidget(new QLabel(i18n("Maximum:"), this));
-	KIntSpinBox *maxstrokes = new KIntSpinBox(this);
+	QSpinBox *maxstrokes = new QSpinBox(this);
 	maxstrokes->setRange( holeInfo->lowestMaxStrokes(), 30 );
 	maxstrokes->setSingleStep( 1 );
 	maxstrokes->setWhatsThis( i18n("Maximum number of strokes player can take on this hole."));
@@ -296,7 +293,7 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	maxstrokes->setSpecialValueText(i18n("Unlimited"));
 	maxstrokes->setValue(holeInfo->maxStrokes());
 	hlayout->addWidget(maxstrokes);
-	connect(maxstrokes, static_cast<void (KIntSpinBox::*)(int)>(&KIntSpinBox::valueChanged), this, &HoleConfig::maxStrokesChanged);
+	connect(maxstrokes, QOverload<int>::of(&QSpinBox::valueChanged), this, &HoleConfig::maxStrokesChanged);
 
 	QCheckBox *check = new QCheckBox(i18n("Show border walls"), this);
 	check->setChecked(holeInfo->borderWalls());
@@ -445,9 +442,19 @@ void StrokeCircle::paint (QPainter *p, const QStyleOptionGraphicsItem *, QWidget
 /////////////////////////////////////////
 
 KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const QString &filename, QWidget *parent)
-: QGraphicsView(parent)
-, m_factory(factory)
-, holeInfo(g_world)
+: QGraphicsView(parent),
+ m_factory(factory),
+ m_soundBlackHole(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/blackhole.wav"))),
+ m_soundBlackHoleEject(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/blackholeeject.wav"))),
+ m_soundBlackHolePutIn(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/blackholeputin.wav"))),
+ m_soundBumper(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/bumper.wav"))),
+ m_soundHit(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/hit.wav"))),
+ m_soundHoled(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/holed.wav"))),
+ m_soundHoleINone(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/holeinone.wav"))),
+ m_soundPuddle(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/puddle.wav"))),
+ m_soundWall(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/wall.wav"))),
+ m_soundWooHoo(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/woohoo.wav"))),
+ holeInfo(g_world)
 {
 	setRenderHint(QPainter::Antialiasing);
 	// for mouse control
@@ -473,7 +480,6 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 	lastDelId = -1;
 	m_showInfo = false;
 	ballStateList.canUndo = false;
-	soundDir = KStandardDirs::locate("appdata", "sounds/");
 	dontAddStroke = false;
 	addingNewHole = false;
 	scoreboardHoles = 0;
@@ -486,10 +492,6 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 	recalcHighestHole = false;
 	banner = 0;
 
-#ifdef SOUND
-	m_player = Phonon::createPlayer(Phonon::GameCategory);
-#endif
-
 	holeInfo.setGame(this);
 	holeInfo.setAuthor(i18n("Course Author"));
 	holeInfo.setName(i18n("Course Name"));
@@ -511,15 +513,15 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 
 	setContentsMargins(margin, margin, margin, margin);
 
-	course = new Tagaro::Scene(Kolf::renderer(), "grass");
+	course = new Tagaro::Scene(Kolf::renderer(), QStringLiteral("grass"));
 	course->setMainView(this); //this does this->setScene(course)
 	courseBoard = new Tagaro::Board;
 	courseBoard->setLogicalSize(QSizeF(400, 400));
 	course->addItem(courseBoard);
 
-	if( filename.contains( "intro" ) )
+	if( filename.contains( QLatin1String("intro") ) )
 	{
-		banner = new Tagaro::SpriteObjectItem(Kolf::renderer(), "intro_foreground", courseBoard);
+		banner = new Tagaro::SpriteObjectItem(Kolf::renderer(), QStringLiteral("intro_foreground"), courseBoard);
 		banner->setSize(400, 132);
 		banner->setPos(0, 32);
 		banner->setZValue(3); //on the height of a puddle (above slopes and sands, below any objects)
@@ -602,6 +604,47 @@ KolfGame::KolfGame(const Kolf::ItemFactory& factory, PlayerList *players, const
 	putterTimerMsec = 20;
 }
 
+void KolfGame::playSound(Sound soundType)
+{
+	if (m_sound) {
+		switch (soundType) {
+			case Sound::BlackHole:
+				m_soundBlackHole.start();
+				break;
+			case Sound::BlackHoleEject:
+				m_soundBlackHoleEject.start();
+				break;
+			case Sound::BlackHolePutIn:
+				m_soundBlackHolePutIn.start();
+				break;
+			case Sound::Bumper:
+				m_soundBumper.start();
+				break;
+			case Sound::Hit:
+				m_soundHit.start();
+				break;
+			case Sound::Holed:
+				m_soundHoled.start();
+				break;
+			case Sound::HoleINone:
+				m_soundHoleINone.start();
+				break;
+			case Sound::Puddle:
+				m_soundPuddle.start();
+				break;
+			case Sound::Wall:
+				m_soundWall.start();
+				break;
+			case Sound::WooHoo:
+				m_soundWooHoo.start();
+				break;
+			default:
+				qWarning() << "There was a request to play an unknown sound.";
+				break;
+		}
+	}
+}
+
 void KolfGame::startFirstHole(int hole)
 {
 	if (curHole > 0) // if there was saved game, sync scoreboard
@@ -609,7 +652,7 @@ void KolfGame::startFirstHole(int hole)
 	{
 		for (; scoreboardHoles < curHole; ++scoreboardHoles)
 		{
-			cfgGroup = KConfigGroup(cfg->group(QString("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
+			cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
 			emit newHole(cfgGroup.readEntry("par", 3));
 		}
 
@@ -645,9 +688,6 @@ KolfGame::~KolfGame()
 	}
 
 	delete cfg;
-#ifdef SOUND
-	delete m_player;
-#endif
 }
 
 void KolfGame::setModified(bool mod)
@@ -1037,7 +1077,7 @@ void KolfGame::timeout()
 	if (curState == Stopped && inPlay)
 	{
 		inPlay = false;
-		QTimer::singleShot(0, this, SLOT(shotDone()));
+		QTimer::singleShot(0, this, &KolfGame::shotDone);
 	}
 
 	if (curState == Holed && inPlay)
@@ -1050,13 +1090,11 @@ void KolfGame::timeout()
 
 		if (curScore == 1)
 		{
-			playSound("holeinone");
+			playSound(Sound::HoleINone);
 		}
 		else if (curScore <= holeInfo.par())
 		{
-			// I don't have a sound!!
-			// *sob*
-			// playSound("woohoo");
+			playSound(Sound::WooHoo);
 		}
 
 		(*curPlayer).ball()->setZValue((*curPlayer).ball()->zValue() + .1 - (.1)/(curScore));
@@ -1070,12 +1108,12 @@ void KolfGame::timeout()
 				(*curPlayer).addStrokeToHole(curHole);
 				emit scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
 			}
-			QTimer::singleShot(600, this, SLOT(holeDone()));
+			QTimer::singleShot(600, this, &KolfGame::holeDone);
 		}
 		else
 		{
 			inPlay = false;
-			QTimer::singleShot(0, this, SLOT(shotDone()));
+			QTimer::singleShot(0, this, &KolfGame::shotDone);
 		}
 	}
 }
@@ -1210,12 +1248,12 @@ void KolfGame::putterTimeout()
 				if (al > 45)
 				{
 					deg = putter->curDeg() - 45 + rand() % 90;
-					strength -= rand() % (int)strength;
+					strength -= qrand() % (int)strength;
 				}
 				else if (!finishStroking)
 				{
 					deg = putter->curDeg() - 45 + rand() % 90;
-					strength -= rand() % (int)strength;
+					strength -= qrand() % (int)strength;
 				}
 				else
 					deg = putter->curDeg() + (int)(strokeCircle->value() / 3);
@@ -1377,7 +1415,7 @@ void KolfGame::shotDone()
 			const QString placeOutside = i18n("Drop Outside of Hazard");
 			const QString rehit = i18n("Rehit From Last Location");
 			options << placeOutside << rehit;
-			const QString choice = KComboBoxDialog::getItem(i18n("What would you like to do for your next shot?"), i18n("%1 is in a Hazard", (*it).name()), options, placeOutside, "hazardOptions");
+			const QString choice = KComboBoxDialog::getItem(i18n("What would you like to do for your next shot?"), i18n("%1 is in a Hazard", (*it).name()), options, placeOutside, QStringLiteral("hazardOptions"));
 
 			if (choice == placeOutside)
 			{
@@ -1456,11 +1494,11 @@ void KolfGame::shotDone()
 			if (allPlayersDone())
 			{
 				startNextHole();
-				QTimer::singleShot(100, this, SLOT(emitMax()));
+				QTimer::singleShot(100, this, &KolfGame::emitMax);
 				return;
 			}
 
-			QTimer::singleShot(100, this, SLOT(emitMax()));
+			QTimer::singleShot(100, this, &KolfGame::emitMax);
 		}
 	}
 
@@ -1493,8 +1531,7 @@ void KolfGame::emitMax()
 
 void KolfGame::startBall(const Vector &velocity)
 {
-	playSound("hit");
-
+	playSound(Sound::Hit);
 	emit inPlayStart();
 	putter->setVisible(false);
 
@@ -1547,7 +1584,7 @@ void KolfGame::sayWhosGoing()
 {
 	if (players->count() >= 2)
 	{
-		KMessageBox::information(this, i18n("%1 will start off.", (*curPlayer).name()), i18n("New Hole"), "newHole");
+		KMessageBox::information(this, i18n("%1 will start off.", (*curPlayer).name()), i18n("New Hole"), QStringLiteral("newHole"));
 	}
 }
 
@@ -1685,7 +1722,7 @@ void KolfGame::startNextHole()
 
 		for (; scoreboardHoles < curHole; ++scoreboardHoles)
 		{
-			cfgGroup = KConfigGroup(cfg->group(QString("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
+			cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-hole@-50,-50|0").arg(scoreboardHoles + 1)));
 			emit newHole(cfgGroup.readEntry("par", 3));
 		}
 
@@ -1708,11 +1745,11 @@ void KolfGame::startNextHole()
 void KolfGame::showInfoDlg(bool addDontShowAgain)
 {
 	KMessageBox::information(parentWidget(),
-			i18n("Course name: %1", holeInfo.name()) + QString("\n")
-			+ i18n("Created by %1", holeInfo.author()) + QString("\n")
+			i18n("Course name: %1", holeInfo.name()) + QStringLiteral("\n")
+			+ i18n("Created by %1", holeInfo.author()) + QStringLiteral("\n")
 			+ i18np("%1 hole", "%1 holes", highestHole),
 			i18n("Course Information"),
-			addDontShowAgain? holeInfo.name() + QString(" ") + holeInfo.author() : QString());
+			addDontShowAgain? holeInfo.name() + QStringLiteral(" ") + holeInfo.author() : QString());
 }
 
 void KolfGame::openFile()
@@ -1740,13 +1777,13 @@ void KolfGame::openFile()
 	// we do this here for the hell of it.
 	// there is no fake id, by the way,
 	// because it's old and when i added ids i forgot to change it.
-	cfgGroup = KConfigGroup(cfg->group(QString("0-course@-50,-50")));
+	cfgGroup = KConfigGroup(cfg->group(QStringLiteral("0-course@-50,-50")));
 	holeInfo.setAuthor(cfgGroup.readEntry("author", holeInfo.author()));
 	holeInfo.setName(cfgGroup.readEntry("Name", holeInfo.name()));
 	holeInfo.setUntranslatedName(cfgGroup.readEntryUntranslated("Name", holeInfo.untranslatedName()));
 	emit titleChanged(holeInfo.name());
 
-	cfgGroup = KConfigGroup(KSharedConfig::openConfig(filename), QString("%1-hole@-50,-50|0").arg(curHole));
+	cfgGroup = KConfigGroup(KSharedConfig::openConfig(filename), QStringLiteral("%1-hole@-50,-50|0").arg(curHole));
 	curPar = cfgGroup.readEntry("par", 3);
 	holeInfo.setPar(curPar);
 	holeInfo.borderWallsChanged(cfgGroup.readEntry("borderWalls", holeInfo.borderWalls()));
@@ -1767,12 +1804,12 @@ void KolfGame::openFile()
 		cfgGroup = KConfigGroup(cfg->group(*it));
 
 		const int len = (*it).length();
-		const int dashIndex = (*it).indexOf("-");
-		const int holeNum = (*it).left(dashIndex).toInt();
+		const int dashIndex = (*it).indexOf(QLatin1String("-"));
+		const int holeNum = (*it).leftRef(dashIndex).toInt();
 		if (holeNum > _highestHole)
 			_highestHole = holeNum;
 
-		const int atIndex = (*it).indexOf("@");
+		const int atIndex = (*it).indexOf(QLatin1String("@"));
 		const QString name = (*it).mid(dashIndex + 1, atIndex - (dashIndex + 1));
 
 		if (holeNum != curHole)
@@ -1786,13 +1823,13 @@ void KolfGame::openFile()
 		numItems++;
 
 
-		const int commaIndex = (*it).indexOf(",");
-		const int pipeIndex = (*it).indexOf("|");
-		const int x = (*it).mid(atIndex + 1, commaIndex - (atIndex + 1)).toInt();
-		const int y = (*it).mid(commaIndex + 1, pipeIndex - (commaIndex + 1)).toInt();
+		const int commaIndex = (*it).indexOf(QLatin1String(","));
+		const int pipeIndex = (*it).indexOf(QLatin1String("|"));
+		const int x = (*it).midRef(atIndex + 1, commaIndex - (atIndex + 1)).toInt();
+		const int y = (*it).midRef(commaIndex + 1, pipeIndex - (commaIndex + 1)).toInt();
 
 		// will tell where ball is
-		if (name == "ball")
+		if (name == QLatin1String("ball"))
 		{
 			for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
 				(*it).ball()->setPos(x, y);
@@ -1800,7 +1837,7 @@ void KolfGame::openFile()
 			continue;
 		}
 
-		const int id = (*it).right(len - (pipeIndex + 1)).toInt();
+		const int id = (*it).rightRef(len - (pipeIndex + 1)).toInt();
 
 		QGraphicsItem* newItem = m_factory.createInstance(name, courseBoard, g_world);
 		if (newItem)
@@ -1825,14 +1862,14 @@ void KolfGame::openFile()
 			cfgGroup = KConfigGroup(cfg->group(makeGroup(id, curHole, sceneItem->name(), x, y)));
 			sceneItem->load(&cfgGroup);
 		}
-		else if (name != "hole" && !missingPlugins.contains(name))
+		else if (name != QLatin1String("hole") && !missingPlugins.contains(name))
 			missingPlugins.append(name);
 
 	}
 
 	if (!missingPlugins.empty())
 	{
-		KMessageBox::informationList(this, QString("<p>") + i18n("This hole uses the following plugins, which you do not have installed:") + QString("</p>"), missingPlugins, QString(), QString("%1 warning").arg(holeInfo.untranslatedName() + QString::number(curHole)));
+		KMessageBox::informationList(this, QStringLiteral("<p>") + i18n("This hole uses the following plugins, which you do not have installed:") + QStringLiteral("</p>"), missingPlugins, QString(), QStringLiteral("%1 warning").arg(holeInfo.untranslatedName() + QString::number(curHole)));
 	}
 
 	lastDelId = -1;
@@ -2110,14 +2147,22 @@ void KolfGame::randHole()
 
 void KolfGame::save()
 {
-	if (filename.isNull())
+	if (filename.isEmpty())
 	{
-		QString newfilename = KFileDialog::getSaveFileName(KUrl("kfiledialog:///kourses"), 
-				"application/x-kourse", this, i18n("Pick Kolf Course to Save To"));
-		if (newfilename.isNull())
-			return;
-
-		setFilename(newfilename);
+		QPointer<QFileDialog> fileSaveDialog = new QFileDialog(this);
+		fileSaveDialog->setWindowTitle(i18nc("@title:window", "Pick Kolf Course to Save To"));
+		fileSaveDialog->setMimeTypeFilters(QStringList(QStringLiteral("application/x-kourse")));
+		fileSaveDialog->setAcceptMode(QFileDialog::AcceptSave);
+		if (fileSaveDialog->exec() == QDialog::Accepted) {
+			QUrl newfile = fileSaveDialog->selectedUrls().first();
+			if (newfile.isEmpty()) {
+				return;
+			}
+			else {
+				setFilename(newfile.url());
+			}
+		}
+		delete fileSaveDialog;
 	}
 
 	emit parChanged(curHole, holeInfo.par());
@@ -2128,7 +2173,7 @@ void KolfGame::save()
 	// wipe out all groups from this hole
 	for (QStringList::const_iterator it = groups.begin(); it != groups.end(); ++it)
 	{
-		int holeNum = (*it).left((*it).indexOf("-")).toInt();
+		int holeNum = (*it).leftRef((*it).indexOf(QLatin1String("-"))).toInt();
 		if (holeNum == curHole)
 			cfg->deleteGroup(*it);
 	}
@@ -2143,15 +2188,15 @@ void KolfGame::save()
 	}
 
 	// save where ball starts (whiteBall tells all)
-	cfgGroup = KConfigGroup(cfg->group(QString("%1-ball@%2,%3").arg(curHole).arg((int)whiteBall->x()).arg((int)whiteBall->y())));
+	cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-ball@%2,%3").arg(curHole).arg((int)whiteBall->x()).arg((int)whiteBall->y())));
 	cfgGroup.writeEntry("dummykey", true);
 
-	cfgGroup = KConfigGroup(cfg->group(QString("0-course@-50,-50")));
+	cfgGroup = KConfigGroup(cfg->group(QStringLiteral("0-course@-50,-50")));
 	cfgGroup.writeEntry("author", holeInfo.author());
 	cfgGroup.writeEntry("Name", holeInfo.untranslatedName());
 
 	// save hole info
-	cfgGroup = KConfigGroup(cfg->group(QString("%1-hole@-50,-50|0").arg(curHole)));
+	cfgGroup = KConfigGroup(cfg->group(QStringLiteral("%1-hole@-50,-50|0").arg(curHole)));
 	cfgGroup.writeEntry("par", holeInfo.par());
 	cfgGroup.writeEntry("maxstrokes", holeInfo.maxStrokes());
 	cfgGroup.writeEntry("borderWalls", holeInfo.borderWalls());
@@ -2243,28 +2288,6 @@ void KolfGame::setSelectedItem(CanvasItem* citem)
 	}
 }
 
-#ifdef SOUND
-void KolfGame::playSound(const QString& file, float vol)
-{
-	if (m_sound)
-	{
-		QString resFile = soundDir + file + QString::fromLatin1(".wav");
-
-		// not needed when all of the files are in the distribution
-		//if (!QFile::exists(resFile))
-		//return;
-		if (vol > 1)
-			vol = 1;
-		m_player->setCurrentSource(resFile);
-		m_player->play();
-	}
-}
-#else //SOUND
-void KolfGame::playSound( const QString&, float )
-{
-}
-#endif //SOUND
-
 void HoleInfo::borderWallsChanged(bool yes)
 {
 	m_borderWalls = yes;
@@ -2310,7 +2333,7 @@ void KolfGame::setSound(bool yes)
 void KolfGame::courseInfo(CourseInfo &info, const QString& filename)
 {
 	KConfig config(filename);
-	KConfigGroup configGroup (config.group(QString("0-course@-50,-50")));
+	KConfigGroup configGroup (config.group(QStringLiteral("0-course@-50,-50")));
 	info.author = configGroup.readEntry("author", info.author);
 	info.name = configGroup.readEntry("Name", configGroup.readEntry("name", info.name));
 	info.untranslatedName = configGroup.readEntryUntranslated("Name", configGroup.readEntryUntranslated("name", info.name));
@@ -2319,7 +2342,7 @@ void KolfGame::courseInfo(CourseInfo &info, const QString& filename)
 	unsigned int par= 0;
 	while (1)
 	{
-		QString group = QString("%1-hole@-50,-50|0").arg(hole);
+		QString group = QStringLiteral("%1-hole@-50,-50|0").arg(hole);
 		if (!config.hasGroup(group))
 		{
 			hole--;
@@ -2338,7 +2361,7 @@ void KolfGame::courseInfo(CourseInfo &info, const QString& filename)
 
 void KolfGame::scoresFromSaved(KConfig *config, PlayerList &players)
 {
-	KConfigGroup configGroup(config->group(QString("0 Saved Game")));
+	KConfigGroup configGroup(config->group(QStringLiteral("0 Saved Game")));
 	int numPlayers = configGroup.readEntry("Players", 0);
 	if (numPlayers <= 0)
 		return;
@@ -2374,7 +2397,7 @@ void KolfGame::saveScores(KConfig *config)
 			config->deleteGroup(*it);
 	}
 
-	KConfigGroup configGroup(config->group(QString("0 Saved Game")));
+	KConfigGroup configGroup(config->group(QStringLiteral("0 Saved Game")));
 	configGroup.writeEntry("Players", players->count());
 	configGroup.writeEntry("Course", filename);
 	configGroup.writeEntry("Current Hole", curHole);
