@@ -26,27 +26,32 @@
 #include "scoreboard.h"
 
 #include <KActionCollection>
-#include <KFileDialog>
-#include <KIO/NetAccess>
+#include <KIO/CopyJob>
+#include <KIO/Job>
+#include <KJobWidgets>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KScoreDialog>
 #include <KSelectAction>
-#include <KStandardDirs>
-#include <KStatusBar>
+#include <KSharedConfig>
 #include <KStandardAction>
 #include <KStandardGameAction>
 #include <KStandardGuiItem>
 #include <KToggleAction>
-#include <KUrl>
-#include <KMimeType>
-#include <KGlobal>
+#include <QFileDialog>
 #include <QGridLayout>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTemporaryFile>
 #include <QTimer>
+#include <QUrl>
 
 KolfWindow::KolfWindow()
     : KXmlGuiWindow(0)
 {
-	setObjectName( QLatin1String("Kolf" ));
+	setObjectName( QStringLiteral("Kolf" ));
 	competition = false;
 	game = 0;
 	editor = 0;
@@ -56,17 +61,17 @@ KolfWindow::KolfWindow()
 
 	setupActions();
 
-	m_itemFactory.registerType<Kolf::Slope>("slope", i18n("Slope"));
-	m_itemFactory.registerType<Kolf::Puddle>("puddle", i18n("Puddle"));
-	m_itemFactory.registerType<Kolf::Wall>("wall", i18n("Wall"));
-	m_itemFactory.registerType<Kolf::Cup>("cup", i18n("Cup"), true); //true == addOnNewHole
-	m_itemFactory.registerType<Kolf::Sand>("sand", i18n("Sand"));
-	m_itemFactory.registerType<Kolf::Windmill>("windmill", i18n("Windmill"));
-	m_itemFactory.registerType<Kolf::BlackHole>("blackhole", i18n("Black Hole"));
-	m_itemFactory.registerType<Kolf::Floater>("floater", i18n("Floater"));
-	m_itemFactory.registerType<Kolf::Bridge>("bridge", i18n("Bridge"));
-	m_itemFactory.registerType<Kolf::Sign>("sign", i18n("Sign"));
-	m_itemFactory.registerType<Kolf::Bumper>("bumper", i18n("Bumper"));
+	m_itemFactory.registerType<Kolf::Slope>(QStringLiteral("slope"), i18n("Slope"));
+	m_itemFactory.registerType<Kolf::Puddle>(QStringLiteral("puddle"), i18n("Puddle"));
+	m_itemFactory.registerType<Kolf::Wall>(QStringLiteral("wall"), i18n("Wall"));
+	m_itemFactory.registerType<Kolf::Cup>(QStringLiteral("cup"), i18n("Cup"), true); //true == addOnNewHole
+	m_itemFactory.registerType<Kolf::Sand>(QStringLiteral("sand"), i18n("Sand"));
+	m_itemFactory.registerType<Kolf::Windmill>(QStringLiteral("windmill"), i18n("Windmill"));
+	m_itemFactory.registerType<Kolf::BlackHole>(QStringLiteral("blackhole"), i18n("Black Hole"));
+	m_itemFactory.registerType<Kolf::Floater>(QStringLiteral("floater"), i18n("Floater"));
+	m_itemFactory.registerType<Kolf::Bridge>(QStringLiteral("bridge"), i18n("Bridge"));
+	m_itemFactory.registerType<Kolf::Sign>(QStringLiteral("sign"), i18n("Sign"));
+	m_itemFactory.registerType<Kolf::Bumper>(QStringLiteral("bumper"), i18n("Bumper"));
 	//NOTE: The plugin mechanism has been removed because it is not used anyway.
 
 	filename = QString();
@@ -88,116 +93,116 @@ void KolfWindow::setupActions()
 	endAction = KStandardGameAction::end(this, SLOT(closeGame()), actionCollection());
 	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
-	saveAction = actionCollection()->addAction(KStandardAction::Save, "game_save", this, SLOT(save()));
+	saveAction = actionCollection()->addAction(KStandardAction::Save, QStringLiteral("game_save"), this, SLOT(save()));
 	saveAction->setText(i18n("Save &Course"));
-	saveAsAction = actionCollection()->addAction(KStandardAction::SaveAs, "game_save_as", this, SLOT(saveAs()));
+	saveAsAction = actionCollection()->addAction(KStandardAction::SaveAs, QStringLiteral("game_save_as"), this, SLOT(saveAs()));
 	saveAsAction->setText(i18n("Save &Course As..."));
 
-	saveGameAction = actionCollection()->addAction("savegame");
+	saveGameAction = actionCollection()->addAction(QStringLiteral("savegame"));
 	saveGameAction->setText(i18n("&Save Game"));
-	connect(saveGameAction, SIGNAL(triggered(bool)), SLOT(saveGame()));
-	saveGameAsAction = actionCollection()->addAction("savegameas");
+	connect(saveGameAction, &QAction::triggered, this, &KolfWindow::saveGame);
+	saveGameAsAction = actionCollection()->addAction(QStringLiteral("savegameas"));
 	saveGameAsAction->setText(i18n("&Save Game As..."));
-	connect(saveGameAsAction, SIGNAL(triggered(bool)), SLOT(saveGameAs()));
+	connect(saveGameAsAction, &QAction::triggered, this, &KolfWindow::saveGameAs);
 
 	loadGameAction = KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
 	highScoreAction = KStandardGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
 
 	// Hole
-	editingAction = new KToggleAction(QIcon::fromTheme( QLatin1String( "document-properties") ), i18n("&Edit"), this);
-	actionCollection()->addAction("editing", editingAction);
-	connect(editingAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	editingAction = new KToggleAction(QIcon::fromTheme( QStringLiteral( "document-properties") ), i18n("&Edit"), this);
+	actionCollection()->addAction(QStringLiteral("editing"), editingAction);
+	connect(editingAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(editingAction, Qt::CTRL+Qt::Key_E);
-	newHoleAction = actionCollection()->addAction("newhole");
-	newHoleAction->setIcon(QIcon::fromTheme( QLatin1String( "document-new" )));
+	newHoleAction = actionCollection()->addAction(QStringLiteral("newhole"));
+	newHoleAction->setIcon(QIcon::fromTheme( QStringLiteral( "document-new" )));
 	newHoleAction->setText(i18n("&New"));
-	connect(newHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(newHoleAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(newHoleAction, Qt::CTRL+Qt::SHIFT+Qt::Key_N);
-	clearHoleAction = actionCollection()->addAction("clearhole");
-	clearHoleAction->setIcon(QIcon::fromTheme( QLatin1String( "edit-clear-locationbar-ltr" )));
+	clearHoleAction = actionCollection()->addAction(QStringLiteral("clearhole"));
+	clearHoleAction->setIcon(QIcon::fromTheme( QStringLiteral( "edit-clear-locationbar-ltr" )));
 	clearHoleAction->setText(KStandardGuiItem::clear().text());
-	connect(clearHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(clearHoleAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(clearHoleAction, Qt::CTRL+Qt::Key_Delete);
-	resetHoleAction = actionCollection()->addAction("resethole");
+	resetHoleAction = actionCollection()->addAction(QStringLiteral("resethole"));
 	resetHoleAction->setText(i18n("&Reset"));
-	connect(resetHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(resetHoleAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(resetHoleAction, Qt::CTRL+Qt::Key_R);
-	undoShotAction = KStandardAction::undo(this, SLOT(emptySlot()), this);
-	actionCollection()->addAction("undoshot", undoShotAction);
+	undoShotAction = KStandardAction::undo(this, &KolfWindow::emptySlot, this);
+	actionCollection()->addAction(QStringLiteral("undoshot"), undoShotAction);
 	undoShotAction->setText(i18n("&Undo Shot"));
 	//replayShotAction = new QAction(i18n("&Replay Shot"), 0, this, SLOT(emptySlot()), actionCollection(), "replay");
 
 	// Go
 	holeAction = new KSelectAction(i18n("Switch to Hole"), this);
-	actionCollection()->addAction("switchhole", holeAction);
-	connect(holeAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	nextAction = actionCollection()->addAction("nexthole");
-	nextAction->setIcon(QIcon::fromTheme( QLatin1String( "go-next" )));
+	actionCollection()->addAction(QStringLiteral("switchhole"), holeAction);
+	connect(holeAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	nextAction = actionCollection()->addAction(QStringLiteral("nexthole"));
+	nextAction->setIcon(QIcon::fromTheme( QStringLiteral( "go-next" )));
 	nextAction->setText(i18n("&Next Hole"));
-	connect(nextAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(nextAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcuts(nextAction, KStandardShortcut::forward());
-	prevAction = actionCollection()->addAction("prevhole");
-	prevAction->setIcon(QIcon::fromTheme( QLatin1String( "go-previous" )));
+	prevAction = actionCollection()->addAction(QStringLiteral("prevhole"));
+	prevAction->setIcon(QIcon::fromTheme( QStringLiteral( "go-previous" )));
 	prevAction->setText(i18n("&Previous Hole"));
-	connect(prevAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(prevAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcuts(prevAction, KStandardShortcut::back());
-	firstAction = actionCollection()->addAction("firsthole");
-	firstAction->setIcon(QIcon::fromTheme( QLatin1String( "go-home" )));
+	firstAction = actionCollection()->addAction(QStringLiteral("firsthole"));
+	firstAction->setIcon(QIcon::fromTheme( QStringLiteral( "go-home" )));
 	firstAction->setText(i18n("&First Hole"));
-	connect(firstAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(firstAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcuts(firstAction, KStandardShortcut::begin());
-	lastAction = actionCollection()->addAction("lasthole");
+	lastAction = actionCollection()->addAction(QStringLiteral("lasthole"));
 	lastAction->setText(i18n("&Last Hole"));
-	connect(lastAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(lastAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(lastAction, Qt::CTRL+Qt::SHIFT+Qt::Key_End); // why not KStandardShortcut::End (Ctrl+End)?
-	randAction = actionCollection()->addAction("randhole");
-	randAction->setIcon(QIcon::fromTheme( QLatin1String( "go-jump" )));
+	randAction = actionCollection()->addAction(QStringLiteral("randhole"));
+	randAction->setIcon(QIcon::fromTheme( QStringLiteral( "go-jump" )));
 	randAction->setText(i18n("&Random Hole"));
-	connect(randAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	connect(randAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 
 	// Settings
 	useMouseAction = new KToggleAction(i18n("Enable &Mouse for Moving Putter"), this);
-	actionCollection()->addAction("usemouse", useMouseAction);
-	connect(useMouseAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	connect(useMouseAction, SIGNAL(toggled(bool)), this, SLOT(useMouseChanged(bool)));
+	actionCollection()->addAction(QStringLiteral("usemouse"), useMouseAction);
+	connect(useMouseAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	connect(useMouseAction, &QAction::toggled, this, &KolfWindow::useMouseChanged);
 	KConfigGroup configGroup(KSharedConfig::openConfig(), "Settings");
 	useMouseAction->setChecked(configGroup.readEntry("useMouse", true));
 
 	useAdvancedPuttingAction = new KToggleAction(i18n("Enable &Advanced Putting"), this);
-	actionCollection()->addAction("useadvancedputting", useAdvancedPuttingAction);
-	connect(useAdvancedPuttingAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), this, SLOT(useAdvancedPuttingChanged(bool)));
+	actionCollection()->addAction(QStringLiteral("useadvancedputting"), useAdvancedPuttingAction);
+	connect(useAdvancedPuttingAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	connect(useAdvancedPuttingAction, &QAction::toggled, this, &KolfWindow::useAdvancedPuttingChanged);
 	useAdvancedPuttingAction->setChecked(configGroup.readEntry("useAdvancedPutting", false));
 
-	showInfoAction = new KToggleAction(QIcon::fromTheme( QLatin1String( "help-about")), i18n("Show &Info"), this);
-	actionCollection()->addAction("showinfo", showInfoAction);
-	connect(showInfoAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
+	showInfoAction = new KToggleAction(QIcon::fromTheme( QStringLiteral( "help-about")), i18n("Show &Info"), this);
+	actionCollection()->addAction(QStringLiteral("showinfo"), showInfoAction);
+	connect(showInfoAction, &QAction::triggered, this, &KolfWindow::emptySlot);
 	actionCollection()->setDefaultShortcut(showInfoAction, Qt::CTRL+Qt::Key_I);
-	connect(showInfoAction, SIGNAL(toggled(bool)), this, SLOT(showInfoChanged(bool)));
+	connect(showInfoAction, &QAction::toggled, this, &KolfWindow::showInfoChanged);
 	showInfoAction->setChecked(configGroup.readEntry("showInfo", true));
 
 	showGuideLineAction = new KToggleAction(i18n("Show Putter &Guideline"), this);
-	actionCollection()->addAction("showguideline", showGuideLineAction);
-	connect(showGuideLineAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	connect(showGuideLineAction, SIGNAL(toggled(bool)), this, SLOT(showGuideLineChanged(bool)));
+	actionCollection()->addAction(QStringLiteral("showguideline"), showGuideLineAction);
+	connect(showGuideLineAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	connect(showGuideLineAction, &QAction::toggled, this, &KolfWindow::showGuideLineChanged);
 	showGuideLineAction->setChecked(configGroup.readEntry("showGuideLine", true));
 
 	KToggleAction *act = new KToggleAction(i18n("Enable All Dialog Boxes"), this);
-	actionCollection()->addAction("enableAll", act);
-	connect(act, SIGNAL(triggered(bool)), SLOT(enableAllMessages()));
+	actionCollection()->addAction(QStringLiteral("enableAll"), act);
+	connect(act, &QAction::triggered, this, &KolfWindow::enableAllMessages);
 
 	soundAction = new KToggleAction(i18n("Play &Sounds"), this);
-	actionCollection()->addAction("sound", soundAction);
-	connect(soundAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	connect(soundAction, SIGNAL(toggled(bool)), this, SLOT(soundChanged(bool)));
+	actionCollection()->addAction(QStringLiteral("sound"), soundAction);
+	connect(soundAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	connect(soundAction, &QAction::toggled, this, &KolfWindow::soundChanged);
 	soundAction->setChecked(configGroup.readEntry("sound", true));
 
-	aboutAction = actionCollection()->addAction("aboutcourse");
+	aboutAction = actionCollection()->addAction(QStringLiteral("aboutcourse"));
 	aboutAction->setText(i18n("&About Course"));
-	connect(aboutAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
-	tutorialAction = actionCollection()->addAction("tutorial");
+	connect(aboutAction, &QAction::triggered, this, &KolfWindow::emptySlot);
+	tutorialAction = actionCollection()->addAction(QStringLiteral("tutorial"));
 	tutorialAction->setText(i18n("&Tutorial"));
-	connect(tutorialAction, SIGNAL(triggered(bool)), SLOT(tutorial()));
+	connect(tutorialAction, &QAction::triggered, this, &KolfWindow::tutorial);
 
 	setupGUI();
 }
@@ -212,14 +217,16 @@ bool KolfWindow::queryClose()
 
 void KolfWindow::startNewGame()
 {
-	NewGameDialog *dialog = 0;
+        NewGameDialog *dialog = nullptr;
 	int firstHole = 1;
 
 	if (loadedGame.isNull())
 	{
 		dialog = new NewGameDialog(filename.isNull());
-		if (dialog->exec() != QDialog::Accepted)
-			goto end;
+                if (dialog->exec() != QDialog::Accepted) {
+                    delete dialog;
+                    return;
+               }
 	}
 
 	players.clear();
@@ -230,9 +237,7 @@ void KolfWindow::startNewGame()
 
 	if (loadedGame.isNull())
 	{
-		PlayerEditor *curEditor = 0;
-		int newId = 1;
-		for (curEditor = dialog->players()->at(newId-1); newId <= dialog->players()->count(); ++newId)
+		for (int newId = 1; newId <= dialog->players()->count(); ++newId)
 		{
 			players.append(Player());
 			players.last().ball()->setColor(dialog->players()->at(newId-1)->color());
@@ -249,7 +254,7 @@ void KolfWindow::startNewGame()
 		KConfigGroup configGroup(config.group("0 Saved Game"));
 
 		if (isTutorial)
-			filename = KGlobal::dirs()->findResource("appdata", "tutorial.kolf");
+			filename = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("tutorial.kolf"));
 		else
 			filename = configGroup.readEntry("Course", QString());
 
@@ -267,45 +272,45 @@ void KolfWindow::startNewGame()
 		scoreboard->newPlayer((*it).name());
 
 	delete spacer;
-	spacer = 0;
+        spacer = nullptr;
 	delete game;
-	game = new KolfGame(m_itemFactory, &players, filename, dummy);
+        game = new KolfGame(m_itemFactory, &players, filename, dummy);
 	game->setStrict(competition);
 
-	connect(game, SIGNAL(newHole(int)), scoreboard, SLOT(newHole(int)));
-	connect(game, SIGNAL(scoreChanged(int,int,int)), scoreboard, SLOT(setScore(int,int,int)));
-	connect(game, SIGNAL(parChanged(int,int)), scoreboard, SLOT(parChanged(int,int)));
-	connect(game, SIGNAL(modifiedChanged(bool)), this, SLOT(updateModified(bool)));
-	connect(game, SIGNAL(newPlayersTurn(Player*)), this, SLOT(newPlayersTurn(Player*)));
-	connect(game, SIGNAL(holesDone()), this, SLOT(gameOver()));
-	connect(game, SIGNAL(checkEditing()), this, SLOT(checkEditing()));
-	connect(game, SIGNAL(editingStarted()), this, SLOT(editingStarted()));
-	connect(game, SIGNAL(editingEnded()), this, SLOT(editingEnded()));
-	connect(game, SIGNAL(inPlayStart()), this, SLOT(inPlayStart()));
-	connect(game, SIGNAL(inPlayEnd()), this, SLOT(inPlayEnd()));
-	connect(game, SIGNAL(maxStrokesReached(QString)), this, SLOT(maxStrokesReached(QString)));
-	connect(game, SIGNAL(largestHole(int)), this, SLOT(updateHoleMenu(int)));
-	connect(game, SIGNAL(titleChanged(QString)), this, SLOT(titleChanged(QString)));
-	connect(game, SIGNAL(newStatusText(QString)), this, SLOT(newStatusText(QString)));
-	connect(game, SIGNAL(currentHole(int)), this, SLOT(setCurrentHole(int)));
-	connect(holeAction, SIGNAL(triggered(QString)), game, SLOT(switchHole(QString)));
-	connect(nextAction, SIGNAL(triggered(bool)), game, SLOT(nextHole()));
-	connect(prevAction, SIGNAL(triggered(bool)), game, SLOT(prevHole()));
-	connect(firstAction, SIGNAL(triggered(bool)), game, SLOT(firstHole()));
-	connect(lastAction, SIGNAL(triggered(bool)), game, SLOT(lastHole()));
-	connect(randAction, SIGNAL(triggered(bool)), game, SLOT(randHole()));
-	connect(editingAction, SIGNAL(triggered(bool)), game, SLOT(toggleEditMode()));
-	connect(newHoleAction, SIGNAL(triggered(bool)), game, SLOT(addNewHole()));
-	connect(clearHoleAction, SIGNAL(triggered(bool)), game, SLOT(clearHole()));
-	connect(resetHoleAction, SIGNAL(triggered(bool)), game, SLOT(resetHole()));
-	connect(undoShotAction, SIGNAL(triggered(bool)), game, SLOT(undoShot()));
-	//connect(replayShotAction, SIGNAL(triggered(bool)), game, SLOT(replay()));
-	connect(aboutAction, SIGNAL(triggered(bool)), game, SLOT(showInfoDlg()));
-	connect(useMouseAction, SIGNAL(toggled(bool)), game, SLOT(setUseMouse(bool)));
-	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), game, SLOT(setUseAdvancedPutting(bool)));
-	connect(soundAction, SIGNAL(toggled(bool)), game, SLOT(setSound(bool)));
-	connect(showGuideLineAction, SIGNAL(toggled(bool)), game, SLOT(setShowGuideLine(bool)));
-	connect(showInfoAction, SIGNAL(toggled(bool)), game, SLOT(setShowInfo(bool)));
+	connect(game, &KolfGame::newHole, scoreboard, &ScoreBoard::newHole);
+	connect(game, &KolfGame::scoreChanged, scoreboard, &ScoreBoard::setScore);
+	connect(game, &KolfGame::parChanged, scoreboard, &ScoreBoard::parChanged);
+	connect(game, &KolfGame::modifiedChanged, this, &KolfWindow::updateModified);
+	connect(game, &KolfGame::newPlayersTurn, this, &KolfWindow::newPlayersTurn);
+	connect(game, &KolfGame::holesDone, this, &KolfWindow::gameOver);
+	connect(game, &KolfGame::checkEditing, this, &KolfWindow::checkEditing);
+	connect(game, &KolfGame::editingStarted, this, &KolfWindow::editingStarted);
+	connect(game, &KolfGame::editingEnded, this, &KolfWindow::editingEnded);
+	connect(game, &KolfGame::inPlayStart, this, &KolfWindow::inPlayStart);
+	connect(game, &KolfGame::inPlayEnd, this, &KolfWindow::inPlayEnd);
+	connect(game, &KolfGame::maxStrokesReached, this, &KolfWindow::maxStrokesReached);
+	connect(game, &KolfGame::largestHole, this, &KolfWindow::updateHoleMenu);
+	connect(game, &KolfGame::titleChanged, this, &KolfWindow::titleChanged);
+	connect(game, &KolfGame::newStatusText, this, &KolfWindow::newStatusText);
+	connect(game, QOverload<int>::of(&KolfGame::currentHole), this, &KolfWindow::setCurrentHole);
+	connect(holeAction, &QAction::triggered, game, QOverload<int>::of(&KolfGame::switchHole));
+	connect(nextAction, &QAction::triggered, game, &KolfGame::nextHole);
+	connect(prevAction, &QAction::triggered, game, &KolfGame::prevHole);
+	connect(firstAction, &QAction::triggered, game, &KolfGame::firstHole);
+	connect(lastAction, &QAction::triggered, game, &KolfGame::lastHole);
+	connect(randAction, &QAction::triggered, game, &KolfGame::randHole);
+	connect(editingAction, &QAction::triggered, game, &KolfGame::toggleEditMode);
+	connect(newHoleAction, &QAction::triggered, game, &KolfGame::addNewHole);
+	connect(clearHoleAction, &QAction::triggered, game, &KolfGame::clearHole);
+	connect(resetHoleAction, &QAction::triggered, game, &KolfGame::resetHole);
+	connect(undoShotAction, &QAction::triggered, game, &KolfGame::undoShot);
+	//connect(replayShotAction, &QAction::triggered, game, &KolfGame::replay);
+	connect(aboutAction, &QAction::triggered, game, &KolfGame::showInfoDlg);
+	connect(useMouseAction, &QAction::toggled, game, &KolfGame::setUseMouse);
+	connect(useAdvancedPuttingAction, &QAction::toggled, game, &KolfGame::setUseAdvancedPutting);
+	connect(soundAction, &QAction::toggled, game, &KolfGame::setSound);
+	connect(showGuideLineAction, &QAction::toggled, game, &KolfGame::setShowGuideLine);
+	connect(showInfoAction, &QAction::toggled, game, &KolfGame::setShowInfo);
 
 	game->setUseMouse(useMouseAction->isChecked());
 	game->setUseAdvancedPutting(useAdvancedPuttingAction->isChecked());
@@ -338,8 +343,6 @@ void KolfWindow::startNewGame()
 	// so game can do stuff that needs to be done
 	// after things above are connected
 	game->startFirstHole(firstHole);
-
-	end:
 	delete dialog;
 }
 
@@ -352,7 +355,7 @@ void KolfWindow::newGame()
 
 void KolfWindow::tutorial()
 {
-	QString newfilename = KGlobal::dirs()->findResource("appdata", "tutorial.kolfgame");
+	QString newfilename = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("tutorial.kolfgame"));
 	if (newfilename.isNull())
 	        return;
 
@@ -402,7 +405,7 @@ void KolfWindow::closeGame()
 	titleChanged(QString());
 	updateModified(false);
 
-	QTimer::singleShot(100, this, SLOT(createSpacer()));
+	QTimer::singleShot(100, this, &KolfWindow::createSpacer);
 }
 
 void KolfWindow::createSpacer()
@@ -411,11 +414,11 @@ void KolfWindow::createSpacer()
 	spacerPlayers.clear();
 	spacerPlayers.append(Player());
 	spacerPlayers.last().ball()->setColor(Qt::yellow);
-	spacerPlayers.last().setName("player");
+	spacerPlayers.last().setName(QStringLiteral("player"));
 	spacerPlayers.last().setId(1);
 
 	delete spacer;
-	spacer = new KolfGame(m_itemFactory, &spacerPlayers, KGlobal::dirs()->findResource("appdata", "intro"), dummy);
+	spacer = new KolfGame(m_itemFactory, &spacerPlayers, QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("intro")), dummy);
 	spacer->setSound(false);
 	layout->addWidget(spacer, 0, 0);//, Qt::AlignCenter);
 	spacer->ignoreEvents(true);
@@ -490,12 +493,12 @@ void KolfWindow::gameOver()
 		// KScoreDialog makes it very easy :-))
 
 		KScoreDialog *scoreDialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Custom1 | KScoreDialog::Score, this);
-		scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), "Par");
+		scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), QStringLiteral("Par"));
 
 		CourseInfo courseInfo;
 		game->courseInfo(courseInfo, game->curFilename());
 
-		scoreDialog->setConfigGroup(courseInfo.untranslatedName + QString(" Highscores"));
+		scoreDialog->setConfigGroup(qMakePair(QByteArray(courseInfo.untranslatedName.toUtf8() + " Highscores"), i18n("High Scores for %1", courseInfo.name)));
 
 		for (HighScoreList::Iterator it = highScores.begin(); it != highScores.end(); ++it)
 		{
@@ -511,18 +514,18 @@ void KolfWindow::gameOver()
 		scoreDialog->show();
 	}
 
-	QTimer::singleShot(700, this, SLOT(closeGame()));
+	QTimer::singleShot(700, this, &KolfWindow::closeGame);
 }
 
 void KolfWindow::showHighScores()
 {
 	KScoreDialog *scoreDialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Custom1 | KScoreDialog::Score, this);
-	scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), "Par");
+	scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), QStringLiteral("Par"));
 
 	CourseInfo courseInfo;
 	game->courseInfo(courseInfo, game->curFilename());
 
-	scoreDialog->setConfigGroup(courseInfo.untranslatedName + QString(" Highscores"));
+	scoreDialog->setConfigGroup(qMakePair(QByteArray(courseInfo.untranslatedName.toUtf8() + " Highscores"), i18n("High Scores for %1", courseInfo.name)));
 	scoreDialog->setComment(i18n("High Scores for %1", courseInfo.name));
 	scoreDialog->show();
 }
@@ -543,27 +546,39 @@ void KolfWindow::save()
 
 void KolfWindow::saveAs()
 {
-	QString newfilename = KFileDialog::getSaveFileName( KUrl("kfiledialog:///kourses"),
-                                  "application/x-kourse", this, i18n("Pick Kolf Course to Save To"));
-	if (!newfilename.isNull())
-	{
-		filename = newfilename;
-		game->setFilename(filename);
-		game->save();
-		game->setFocus();
+	QPointer<QFileDialog> fileSaveDialog = new QFileDialog(this);
+	fileSaveDialog->setWindowTitle(i18nc("@title:window", "Pick Kolf Course to Save To"));
+	fileSaveDialog->setMimeTypeFilters(QStringList(QStringLiteral("application/x-kourse")));
+	fileSaveDialog->setAcceptMode(QFileDialog::AcceptSave);
+	if (fileSaveDialog->exec() == QDialog::Accepted) {
+		QUrl newfile = fileSaveDialog->selectedUrls().first();
+		if (!newfile.isEmpty()) {
+			filename = newfile.url();
+			game->setFilename(filename);
+			game->save();
+			game->setFocus();
+		}
 	}
+	delete fileSaveDialog;
 }
 
 void KolfWindow::saveGameAs()
 {
-	QString newfilename = KFileDialog::getSaveFileName( KUrl("kfiledialog:///savedkolf"),
-                                    "application/x-kolf", this, i18n("Pick Saved Game to Save To"));
-	if (newfilename.isNull())
-		return;
-
-	loadedGame = newfilename;
-
-	saveGame();
+		QPointer<QFileDialog> fileSaveDialog = new QFileDialog(this);
+		fileSaveDialog->setWindowTitle(i18nc("@title:window", "Pick Saved Game to Save To"));
+		fileSaveDialog->setMimeTypeFilters(QStringList(QStringLiteral("application/x-kolf")));
+		fileSaveDialog->setAcceptMode(QFileDialog::AcceptSave);
+		if (fileSaveDialog->exec() == QDialog::Accepted) {
+			QUrl newfile = fileSaveDialog->selectedUrls().first();
+			if (newfile.isEmpty()) {
+				return;
+			}
+			else {
+				loadedGame = newfile.url();
+				saveGame();
+			}
+		}
+		delete fileSaveDialog;
 }
 
 void KolfWindow::saveGame()
@@ -587,35 +602,48 @@ void KolfWindow::saveGame()
 
 void KolfWindow::loadGame()
 {
-	loadedGame = KFileDialog::getOpenFileName( KUrl("kfiledialog:///savedkolf"),
-			 QLatin1String("application/x-kolf"), this, i18n("Pick Kolf Saved Game"));
-
-	if (loadedGame.isNull())
-		return;
-
-	isTutorial = false;
-	startNewGame();
+	QPointer<QFileDialog> fileLoadDialog = new QFileDialog(this);
+	fileLoadDialog->setWindowTitle(i18nc("@title:window", "Pick Kolf Saved Game"));
+	fileLoadDialog->setMimeTypeFilters(QStringList(QStringLiteral("application/x-kolf")));
+	fileLoadDialog->setAcceptMode(QFileDialog::AcceptOpen);
+	fileLoadDialog->setFileMode(QFileDialog::ExistingFile);
+	if (fileLoadDialog->exec() == QDialog::Accepted) {
+		QUrl loadedGame = fileLoadDialog->selectedUrls().first();
+		if (loadedGame.isEmpty()) {
+			return;
+		}
+		else {
+			isTutorial = false;
+			startNewGame();
+		}
+	}
+	delete fileLoadDialog;
 }
 
 // called by main for command line files
-void KolfWindow::openUrl(KUrl url)
+void KolfWindow::openUrl(const QUrl &url)
 {
-	QString target;
-	if (KIO::NetAccess::download(url, target, this))
+	QTemporaryFile tempFile;
+	tempFile.open();
+	KIO::FileCopyJob *job = KIO::file_copy(url, QUrl::fromLocalFile(tempFile.fileName()), -1, KIO::Overwrite);
+	KJobWidgets::setWindow(job, this);
+	job->exec();
+	if (!job->error())
 	{
 		isTutorial = false;
-		QString mimeType = KMimeType::findByPath(target)->name();
-		if (mimeType == "application/x-kourse")
-			filename = target;
-		else if (mimeType == "application/x-kolf")
-			loadedGame = target;
+		QMimeDatabase db;
+		QString mimeType = db.mimeTypeForFile(tempFile).name();
+		if (mimeType == QLatin1String("application/x-kourse"))
+			filename = tempFile.fileName();
+		else if (mimeType == QLatin1String("application/x-kolf"))
+			loadedGame = tempFile.fileName();
 		else
 		{
 			closeGame();
 			return;
 		}
 
-		QTimer::singleShot(10, this, SLOT(startNewGame()));
+		QTimer::singleShot(10, this, &KolfWindow::startNewGame);
 	}
 	else
 		closeGame();
@@ -645,11 +673,11 @@ void KolfWindow::editingStarted()
 {
 	delete editor;
 	editor = new Editor(m_itemFactory, dummy);
-	editor->setObjectName( QLatin1String( "Editor" ) );
-	connect(editor, SIGNAL(addNewItem(QString)), game, SLOT(addNewObject(QString)));
-	connect(editor, SIGNAL(changed()), game, SLOT(setModified()));
-	connect(editor, SIGNAL(addNewItem(QString)), this, SLOT(setHoleFocus()));
-	connect(game, SIGNAL(newSelectedItem(CanvasItem*)), editor, SLOT(setItem(CanvasItem*)));
+	editor->setObjectName( QStringLiteral( "Editor" ) );
+	connect(editor, &Editor::addNewItem, game, &KolfGame::addNewObject);
+	connect(editor, &Editor::changed, game, &KolfGame::setModified);
+	connect(editor, &Editor::addNewItem, this, &KolfWindow::setHoleFocus);
+	connect(game, &KolfGame::newSelectedItem, editor, &Editor::setItem);
 
 	scoreboard->hide();
 
