@@ -20,32 +20,33 @@
 #include "newgame.h"
 #include "game.h"
 
-#include <KUrl>
 #include <QBoxLayout>
+#include <QFileDialog>
 #include <QLabel>
 #include <QListWidget>
-#include <KFileDialog>
-#include <KMessageBox>
 #include <QPushButton>
+#include <QStandardPaths>
+#include <QUrl>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KScoreDialog>
 #include <KSeparator>
-#include <KStandardDirs>
-#include <KGlobal>
-#include <KDialog>
+#include <KSharedConfig>
+
 NewGameDialog::NewGameDialog(bool enableCourses)
 	: KPageDialog()
 {
 	setWindowTitle(i18n("New Game"));
 	buttonBox()->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	setMinimumSize(640,310);
-	connect(buttonBox(), SIGNAL(accepted()), this, SLOT(slotOk()));
+	connect(buttonBox(), &QDialogButtonBox::accepted, this, &NewGameDialog::slotOk);
 
 	setFaceType(KPageDialog::Tree);
 	this->enableCourses = enableCourses;
 
 	KSharedConfig::Ptr config = KSharedConfig::openConfig();
         // following use this group
-        KConfigGroup configGroup(config->group(QString("New Game Dialog Mode")));
+        KConfigGroup configGroup(config->group(QStringLiteral("New Game Dialog Mode")));
 
 	// lots o' colors :)
 	startColors << Qt::blue << Qt::red << Qt::yellow << Qt::lightGray << Qt::cyan << Qt::darkBlue << Qt::magenta << Qt::darkGray << Qt::darkMagenta << Qt::darkYellow;
@@ -54,13 +55,11 @@ NewGameDialog::NewGameDialog(bool enableCourses)
     	addPage(playerPage, i18n("Players"));
 
 	QVBoxLayout *bigLayout = new QVBoxLayout(playerPage);
-        //QT5 bigLayout->setMargin( marginHint() );
-        //QT5 bigLayout->setSpacing( spacingHint() );
 
 	addButton = new QPushButton(i18n("&New Player"), playerPage);
 	bigLayout->addWidget(addButton);
 
-	connect(addButton, SIGNAL(clicked()), this, SLOT(addPlayer()));
+	connect(addButton, &QPushButton::clicked, this, &NewGameDialog::addPlayer);
 
 	scroller = new QScrollArea(playerPage);
 	bigLayout->addWidget(scroller);
@@ -68,7 +67,7 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 	scroller->setWidget(playersWidget);
 	new QVBoxLayout(playersWidget);
 
-	QMap<QString, QString> entries = config->entryMap("New Game Dialog");
+	QMap<QString, QString> entries = config->entryMap(QStringLiteral("New Game Dialog"));
 	int i = 0;
 	for (QMap<QString, QString>::Iterator it = entries.begin(); it != entries.end(); ++it)
 	{
@@ -96,11 +95,8 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		pageItem->setHeader(i18n("Course"));
 		addPage(pageItem);
 		QVBoxLayout *coursePageLayout = new QVBoxLayout(coursePage);
-                //QT5 coursePageLayout->setMargin( marginHint() );
-                //QT5 coursePageLayout->setSpacing( spacingHint() );
 
 		QHBoxLayout *hlayout = new QHBoxLayout;
-                //QT5 hlayout->setSpacing( spacingHint() );
                 coursePageLayout->addLayout( hlayout );
 
 
@@ -108,7 +104,16 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		externCourses = configGroup.readEntry("extra",QStringList());
 
 		/// course loading
-		const QStringList items = externCourses + KGlobal::dirs()->findAllResources("appdata", "courses/*");
+		QStringList files;
+		const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("courses"), QStandardPaths::LocateDirectory);
+		Q_FOREACH (const QString& dir, dirs) {
+			const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*"), QDir::Files);
+			Q_FOREACH (const QString& file, fileNames) {
+				files.append(dir + '/' + file);
+			}
+		}
+		const QStringList items = externCourses + files;
+
 		QStringList nameList;
 		const QString lastCourse(configGroup.readEntry("course", ""));
 		int curItem = 0;
@@ -135,11 +140,10 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		hlayout->addWidget(courseList);
 		courseList->addItems(nameList);
 		courseList->setCurrentRow(curItem);
-		connect(courseList, SIGNAL(currentRowChanged(int)), this, SLOT(courseSelected(int)));
-		connect(courseList, SIGNAL(itemSelectionChanged()), this, SLOT(selectionChanged()));
+		connect(courseList, &QListWidget::currentRowChanged, this, &NewGameDialog::courseSelected);
+		connect(courseList, &QListWidget::itemSelectionChanged, this, &NewGameDialog::selectionChanged);
 
 		QVBoxLayout *detailLayout = new QVBoxLayout;
-                //QT5 detailLayout->setSpacing( spacingHint() );
                 hlayout->addLayout( detailLayout );
 		name = new QLabel(coursePage);
 		detailLayout->addWidget(name);
@@ -147,7 +151,6 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		detailLayout->addWidget(author);
 
 		QHBoxLayout *minorLayout = new QHBoxLayout;
-                //QT5 minorLayout->setSpacing( spacingHint() );
                 detailLayout->addLayout( minorLayout );
 		par = new QLabel(coursePage);
 		minorLayout->addWidget(par);
@@ -156,23 +159,22 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 
 		detailLayout->addStretch();
 		QPushButton *scores = new QPushButton(i18n("Highscores"), coursePage);
-		connect(scores, SIGNAL(clicked()), this, SLOT(showHighscores()));
+		connect(scores, &QPushButton::clicked, this, &NewGameDialog::showHighscores);
 		detailLayout->addWidget(scores);
 
 		detailLayout->addStretch();
 		detailLayout->addWidget(new KSeparator(coursePage));
 
 		minorLayout = new QHBoxLayout;
-                //QT5 minorLayout->setSpacing( spacingHint() );
                 detailLayout->addLayout( minorLayout );
 
 		QPushButton *addCourseButton = new QPushButton(i18n("Add..."), coursePage);
 		minorLayout->addWidget(addCourseButton);
-		connect(addCourseButton, SIGNAL(clicked()), this, SLOT(addCourse()));
+		connect(addCourseButton, &QPushButton::clicked, this, &NewGameDialog::addCourse);
 
 		remove = new QPushButton(i18n("Remove"), coursePage);
 		minorLayout->addWidget(remove);
-		connect(remove, SIGNAL(clicked()), this, SLOT(removeCourse()));
+		connect(remove, &QPushButton::clicked, this, &NewGameDialog::removeCourse);
 
 		courseSelected(curItem);
 		selectionChanged();
@@ -185,8 +187,6 @@ NewGameDialog::NewGameDialog(bool enableCourses)
     addPage(pageItem);
 
 	QVBoxLayout *vlayout = new QVBoxLayout(optionsPage);
-        //QT5 vlayout->setMargin( marginHint() );
-        //QT5 vlayout->setSpacing( spacingHint() );
 
 	mode = new QCheckBox(i18n("&Strict mode"), optionsPage);
 	vlayout->addWidget(mode);
@@ -206,7 +206,7 @@ NewGameDialog::~NewGameDialog()
 void NewGameDialog::slotOk()
 {
 	KSharedConfig::Ptr config = KSharedConfig::openConfig();
-	KConfigGroup configGroup(config->group(QString("New Game Dialog Mode")));
+	KConfigGroup configGroup(config->group(QStringLiteral("New Game Dialog Mode")));
 
 	configGroup.writeEntry("competition", mode->isChecked());
 	if (enableCourses)
@@ -236,7 +236,7 @@ void NewGameDialog::courseSelected(int index)
 
 	CourseInfo &curinfo = info[currentCourse];
 
-	name->setText(QString("<strong>%1</strong>").arg(curinfo.name));
+	name->setText(QStringLiteral("<strong>%1</strong>").arg(curinfo.name));
 
 	author->setText(i18n("By %1", curinfo.author));
 	par->setText(i18n("Par %1", curinfo.par));
@@ -246,8 +246,8 @@ void NewGameDialog::courseSelected(int index)
 void NewGameDialog::showHighscores()
 {
 	KScoreDialog *scoreDialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Custom1 | KScoreDialog::Score, this);
-	scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), "Par");
-	scoreDialog->setConfigGroup(info[currentCourse].untranslatedName + QString(" Highscores"));
+	scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), QStringLiteral("Par"));
+	scoreDialog->setConfigGroup(qMakePair(QByteArray(info[currentCourse].untranslatedName.toUtf8() + " Highscores"), i18n("High Scores for %1", info[currentCourse].name)));
 	scoreDialog->setComment(i18n("High Scores for %1", info[currentCourse].name));
 	scoreDialog->show();
 }
@@ -277,8 +277,14 @@ void NewGameDialog::selectionChanged()
 
 void NewGameDialog::addCourse()
 {
-	const QStringList files = KFileDialog::getOpenFileNames( KUrl("kfiledialog:///kourses"),
-			 QString::fromLatin1("application/x-kourse"), this, i18n("Pick Kolf Course"));
+	QPointer<QFileDialog> fileLoadDialog = new QFileDialog(this);
+	fileLoadDialog->setWindowTitle(i18nc("@title:window", "Pick Kolf Course"));
+	fileLoadDialog->setMimeTypeFilters(QStringList(QStringLiteral("application/x-kourse")));
+	fileLoadDialog->setAcceptMode(QFileDialog::AcceptOpen);
+	fileLoadDialog->setFileMode(QFileDialog::ExistingFile);
+	fileLoadDialog->exec();
+        const QStringList files = fileLoadDialog->selectedFiles();
+	delete fileLoadDialog;
 
 	bool hasDuplicates = false;
 
@@ -317,7 +323,7 @@ void NewGameDialog::addPlayer()
 	editors.append(pe);
 	pe->show();
 	playersWidget->layout()->addWidget(pe);
-	connect(pe, SIGNAL(deleteEditor(PlayerEditor*)), this, SLOT(deleteEditor(PlayerEditor*)));
+	connect(pe, &PlayerEditor::deleteEditor, this, &NewGameDialog::deleteEditor);
 
 	enableButtons();
 	playersWidget->setMinimumSize(playersWidget->sizeHint());
@@ -343,11 +349,10 @@ void NewGameDialog::enableButtons()
 
 /////////////////////////
 
-PlayerEditor::PlayerEditor(QString startName, QColor startColor, QWidget *parent)
+PlayerEditor::PlayerEditor(const QString &startName, QColor startColor, QWidget *parent)
 	: QWidget(parent)
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
-	layout->setMargin( KDialog::spacingHint() );
 
 	editor = new KLineEdit(this);
 	layout->addWidget(editor);
@@ -358,7 +363,7 @@ PlayerEditor::PlayerEditor(QString startName, QColor startColor, QWidget *parent
 	colorButton->hide();
 	QPushButton *remove = new QPushButton(i18n("Remove"), this);
 	layout->addWidget(remove);
-	connect(remove, SIGNAL(clicked()), this, SLOT(removeMe()));
+	connect(remove, &QPushButton::clicked, this, &PlayerEditor::removeMe);
 }
 
 void PlayerEditor::removeMe()
